# atomic6ghg
The Atomic6 GHG package has been crafted to help Python developers speed development of tools
for calculating estimates of CO2 equivalent greenhouse gas emissions.

Install it from PyPI:

`pip install atomic6ghg`

## Docs
[Read the Docs on GitHub](https://Glasmor/atomic6ghg.github.io/ghg/)

## Example Application
Checkout the [online calculator](https://orion.predix.io/calculator). It uses all the features of atomic6ghg.

## Sponsorship
Atomic6 GHG is made possible by funding from the General Electric Company and the generous support of developers like 
you!